@@ -1,23 +1,25 @@
 package customtemplates
 
 import (
+	"bytes"
 	"context"
 	"path/filepath"
+	"strings"
 	"testing"
 
 	"github.com/projectdiscovery/gologger"
+	"github.com/projectdiscovery/gologger/levels"
 	"github.com/projectdiscovery/nuclei/v3/pkg/catalog/config"
 	"github.com/projectdiscovery/nuclei/v3/pkg/testutils"
-	osutils "github.com/projectdiscovery/utils/os"
+	"github.com/projectdiscovery/nuclei/v3/pkg/utils"
 	"github.com/stretchr/testify/require"
 )
 
 func TestDownloadCustomTemplatesFromGitHub(t *testing.T) {
-	if osutils.IsOSX() {
-		t.Skip("skipping on macos due to unknown failure (works locally)")
-	}
-
-	gologger.DefaultLogger.SetWriter(&testutils.NoopWriter{})
+	// Capture output to check for rate limit errors
+	outputBuffer := &bytes.Buffer{}
+	gologger.DefaultLogger.SetWriter(&utils.CaptureWriter{Buffer: outputBuffer})
+	gologger.DefaultLogger.SetMaxLevel(levels.LevelDebug)
 
 	templatesDirectory := t.TempDir()
 	config.DefaultConfig.SetTemplatesDir(templatesDirectory)
@@ -29,5 +31,12 @@ func TestDownloadCustomTemplatesFromGitHub(t *testing.T) {
 	require.Nil(t, err, "could not create custom templates manager")
 
 	ctm.Download(context.Background())
+
+	// Check if output contains rate limit error and skip test if so
+	output := outputBuffer.String()
+	if strings.Contains(output, "API rate limit exceeded") {
+		t.Skip("GitHub API rate limit exceeded, skipping test")
+	}
+
 	require.DirExists(t, filepath.Join(templatesDirectory, "github", "projectdiscovery", "nuclei-templates-test"), "cloned directory does not exists")
 }
