@@ -139,7 +139,7 @@ func (i *ListInputProvider) Iterate(callback func(value *contextargs.MetaInput)
 }
 
 // Set normalizes and stores passed input values
-func (i *ListInputProvider) Set(value string) {
+func (i *ListInputProvider) Set(executionId string, value string) {
 	URL := strings.TrimSpace(value)
 	if URL == "" {
 		return
@@ -169,7 +169,12 @@ func (i *ListInputProvider) Set(value string) {
 
 	if i.ipOptions.ScanAllIPs {
 		// scan all ips
-		dnsData, err := protocolstate.Dialer.GetDNSData(urlx.Hostname())
+		dialers := protocolstate.GetDialersWithId(executionId)
+		if dialers == nil {
+			panic("dialers with executionId " + executionId + " not found")
+		}
+
+		dnsData, err := dialers.Fastdialer.GetDNSData(urlx.Hostname())
 		if err == nil {
 			if (len(dnsData.A) + len(dnsData.AAAA)) > 0 {
 				var ips []string
@@ -201,7 +206,12 @@ func (i *ListInputProvider) Set(value string) {
 	ips := []string{}
 	// only scan the target but ipv6 if it has one
 	if i.ipOptions.IPV6 {
-		dnsData, err := protocolstate.Dialer.GetDNSData(urlx.Hostname())
+		dialers := protocolstate.GetDialersWithId(executionId)
+		if dialers == nil {
+			panic("dialers with executionId " + executionId + " not found")
+		}
+
+		dnsData, err := dialers.Fastdialer.GetDNSData(urlx.Hostname())
 		if err == nil && len(dnsData.AAAA) > 0 {
 			// pick/ prefer 1st
 			ips = append(ips, dnsData.AAAA[0])
@@ -228,17 +238,17 @@ func (i *ListInputProvider) Set(value string) {
 }
 
 // SetWithProbe only sets the input if it is live
-func (i *ListInputProvider) SetWithProbe(value string, probe providerTypes.InputLivenessProbe) error {
+func (i *ListInputProvider) SetWithProbe(executionId string, value string, probe providerTypes.InputLivenessProbe) error {
 	probedValue, err := probe.ProbeURL(value)
 	if err != nil {
 		return err
 	}
-	i.Set(probedValue)
+	i.Set(executionId, probedValue)
 	return nil
 }
 
 // SetWithExclusions normalizes and stores passed input values if not excluded
-func (i *ListInputProvider) SetWithExclusions(value string) error {
+func (i *ListInputProvider) SetWithExclusions(executionId string, value string) error {
 	URL := strings.TrimSpace(value)
 	if URL == "" {
 		return nil
@@ -247,7 +257,7 @@ func (i *ListInputProvider) SetWithExclusions(value string) error {
 		i.skippedCount++
 		return nil
 	}
-	i.Set(URL)
+	i.Set(executionId, URL)
 	return nil
 }
 
@@ -273,18 +283,20 @@ func (i *ListInputProvider) initializeInputSources(opts *Options) error {
 		switch {
 		case iputil.IsCIDR(target):
 			ips := expand.CIDR(target)
-			i.addTargets(ips)
+			i.addTargets(options.ExecutionId, ips)
 		case asn.IsASN(target):
 			ips := expand.ASN(target)
-			i.addTargets(ips)
+			i.addTargets(options.ExecutionId, ips)
 		default:
-			i.Set(target)
+			i.Set(options.ExecutionId, target)
 		}
 	}
 
 	// Handle stdin
 	if options.Stdin {
-		i.scanInputFromReader(readerutil.TimeoutReader{Reader: os.Stdin, Timeout: time.Duration(options.InputReadTimeout)})
+		i.scanInputFromReader(
+			options.ExecutionId,
+			readerutil.TimeoutReader{Reader: os.Stdin, Timeout: time.Duration(options.InputReadTimeout)})
 	}
 
 	// Handle target file
@@ -297,7 +309,7 @@ func (i *ListInputProvider) initializeInputSources(opts *Options) error {
 			}
 		}
 		if input != nil {
-			i.scanInputFromReader(input)
+			i.scanInputFromReader(options.ExecutionId, input)
 			_ = input.Close()
 		}
 	}
@@ -317,7 +329,7 @@ func (i *ListInputProvider) initializeInputSources(opts *Options) error {
 			return err
 		}
 		for c := range ch {
-			i.Set(c)
+			i.Set(options.ExecutionId, c)
 		}
 	}
 
@@ -331,7 +343,7 @@ func (i *ListInputProvider) initializeInputSources(opts *Options) error {
 				ips := expand.ASN(target)
 				i.removeTargets(ips)
 			default:
-				i.Del(target)
+				i.Del(options.ExecutionId, target)
 			}
 		}
 	}
@@ -340,19 +352,19 @@ func (i *ListInputProvider) initializeInputSources(opts *Options) error {
 }
 
 // scanInputFromReader scans a line of input from reader and passes it for storage
-func (i *ListInputProvider) scanInputFromReader(reader io.Reader) {
+func (i *ListInputProvider) scanInputFromReader(executionId string, reader io.Reader) {
 	scanner := bufio.NewScanner(reader)
 	for scanner.Scan() {
 		item := scanner.Text()
 		switch {
 		case iputil.IsCIDR(item):
 			ips := expand.CIDR(item)
-			i.addTargets(ips)
+			i.addTargets(executionId, ips)
 		case asn.IsASN(item):
 			ips := expand.ASN(item)
-			i.addTargets(ips)
+			i.addTargets(executionId, ips)
 		default:
-			i.Set(item)
+			i.Set(executionId, item)
 		}
 	}
 }
@@ -371,7 +383,7 @@ func (i *ListInputProvider) isExcluded(URL string) bool {
 	return exists
 }
 
-func (i *ListInputProvider) Del(value string) {
+func (i *ListInputProvider) Del(executionId string, value string) {
 	URL := strings.TrimSpace(value)
 	if URL == "" {
 		return
@@ -401,7 +413,12 @@ func (i *ListInputProvider) Del(value string) {
 
 	if i.ipOptions.ScanAllIPs {
 		// scan all ips
-		dnsData, err := protocolstate.Dialer.GetDNSData(urlx.Hostname())
+		dialers := protocolstate.GetDialersWithId(executionId)
+		if dialers == nil {
+			panic("dialers with executionId " + executionId + " not found")
+		}
+
+		dnsData, err := dialers.Fastdialer.GetDNSData(urlx.Hostname())
 		if err == nil {
 			if (len(dnsData.A) + len(dnsData.AAAA)) > 0 {
 				var ips []string
@@ -433,7 +450,12 @@ func (i *ListInputProvider) Del(value string) {
 	ips := []string{}
 	// only scan the target but ipv6 if it has one
 	if i.ipOptions.IPV6 {
-		dnsData, err := protocolstate.Dialer.GetDNSData(urlx.Hostname())
+		dialers := protocolstate.GetDialersWithId(executionId)
+		if dialers == nil {
+			panic("dialers with executionId " + executionId + " not found")
+		}
+
+		dnsData, err := dialers.Fastdialer.GetDNSData(urlx.Hostname())
 		if err == nil && len(dnsData.AAAA) > 0 {
 			// pick/ prefer 1st
 			ips = append(ips, dnsData.AAAA[0])
@@ -519,9 +541,9 @@ func (i *ListInputProvider) setHostMapStream(data string) {
 	}
 }
 
-func (i *ListInputProvider) addTargets(targets []string) {
+func (i *ListInputProvider) addTargets(executionId string, targets []string) {
 	for _, target := range targets {
-		i.Set(target)
+		i.Set(executionId, target)
 	}
 }
 
