@@ -8,11 +8,11 @@ import (
 	"github.com/projectdiscovery/nuclei/v3/pkg/protocols/common/protocolstate"
 )
 
-func memoizedisOracle(host string, port int) (IsOracleResponse, error) {
+func memoizedisOracle(executionId string, host string, port int) (IsOracleResponse, error) {
 	hash := "isOracle" + ":" + fmt.Sprint(host) + ":" + fmt.Sprint(port)
 
 	v, err, _ := protocolstate.Memoizer.Do(hash, func() (interface{}, error) {
-		return isOracle(host, port)
+		return isOracle(executionId, host, port)
 	})
 	if err != nil {
 		return IsOracleResponse{}, err
