@@ -8,11 +8,11 @@ import (
 	"github.com/projectdiscovery/nuclei/v3/pkg/protocols/common/protocolstate"
 )
 
-func memoizedisVNC(host string, port int) (IsVNCResponse, error) {
+func memoizedisVNC(executionId string, host string, port int) (IsVNCResponse, error) {
 	hash := "isVNC" + ":" + fmt.Sprint(host) + ":" + fmt.Sprint(port)
 
 	v, err, _ := protocolstate.Memoizer.Do(hash, func() (interface{}, error) {
-		return isVNC(host, port)
+		return isVNC(executionId, host, port)
 	})
 	if err != nil {
 		return IsVNCResponse{}, err
