@@ -1,8 +1,11 @@
 package automaticscan
 
 import (
+	"fmt"
+
 	"github.com/pkg/errors"
 	"github.com/projectdiscovery/nuclei/v3/pkg/catalog/config"
+	"github.com/projectdiscovery/nuclei/v3/pkg/catalog/disk"
 	"github.com/projectdiscovery/nuclei/v3/pkg/templates"
 	"github.com/projectdiscovery/nuclei/v3/pkg/types"
 	sliceutil "github.com/projectdiscovery/utils/slice"
@@ -27,7 +30,7 @@ func getTemplateDirs(opts Options) ([]string, error) {
 	}
 	allTemplates = sliceutil.Dedupe(allTemplates)
 	if len(allTemplates) == 0 {
-		return nil, errors.New("no templates found for given input")
+		return nil, fmt.Errorf("%w for given input", disk.ErrNoTemplatesFound)
 	}
 	return allTemplates, nil
 }
