@@ -30,7 +30,8 @@ type Options struct {
 	Token     string `yaml:"token"  validate:"required"`
 	IndexName string `yaml:"index-name"  validate:"required"`
 
-	HttpClient *retryablehttp.Client `yaml:"-"`
+	HttpClient  *retryablehttp.Client `yaml:"-"`
+	ExecutionId string                `yaml:"-"`
 }
 
 type data struct {
@@ -48,6 +49,11 @@ type Exporter struct {
 func New(option *Options) (*Exporter, error) {
 	var ei *Exporter
 
+	dialers := protocolstate.GetDialersWithId(option.ExecutionId)
+	if dialers == nil {
+		return nil, fmt.Errorf("dialers not initialized for %s", option.ExecutionId)
+	}
+
 	var client *http.Client
 	if option.HttpClient != nil {
 		client = option.HttpClient.HTTPClient
@@ -57,8 +63,8 @@ func New(option *Options) (*Exporter, error) {
 			Transport: &http.Transport{
 				MaxIdleConns:        10,
 				MaxIdleConnsPerHost: 10,
-				DialContext:         protocolstate.Dialer.Dial,
-				DialTLSContext:      protocolstate.Dialer.DialTLS,
+				DialContext:         dialers.Fastdialer.Dial,
+				DialTLSContext:      dialers.Fastdialer.DialTLS,
 				TLSClientConfig:     &tls.Config{InsecureSkipVerify: option.SSLVerification},
 			},
 		}
